from dbt.adapters.sqlserver import SQLServerAdapter

from dbt.adapters.synapse import SynapseConnectionManager


class SynapseAdapter(SQLServerAdapter):
    ConnectionManager = SynapseConnectionManager



from dbt.adapters.base import AdapterPlugin

from dbt.adapters.synapse.connections import SynapseConnectionManager, SynapseCredentials
from dbt.adapters.synapse.impl import SynapseAdapter
from dbt.include import synapse

Plugin = AdapterPlugin(
    adapter=SynapseAdapter,
    credentials=SynapseCredentials,
    include_path=synapse.PACKAGE_PATH,
    dependencies=["sqlserver"],
)

__all__ = ["Plugin", "SynapseConnectionManager", "SynapseAdapter", "SynapseCredentials"]



from dataclasses import dataclass

from dbt.adapters.sqlserver import SQLServerConnectionManager, SQLServerCredentials


@dataclass
class SynapseCredentials(SQLServerCredentials):
    @property
    def type(self):
        return "synapse"


class SynapseConnectionManager(SQLServerConnectionManager):
    TYPE = "synapse"
    TOKEN = None
